@@ -15,16 +15,14 @@ class DetectController:
         res = requests.post(f'{self.account.hq}/account/endpoint', headers=self.account.headers, json=params)
         if res.status_code == 200:
             return res.text
-        raise Exception(f'Failed to register endpoint (reason:{res.status_code})')
+        raise Exception(res.text)
 
     @verify_credentials
-    def describe_activity(self, endpoint_id=None, days=7):
-        """ Get a summary of Account activity, or an individual Endpoint """
-        params = dict(id=endpoint_id, days=days)
-        res = requests.get(f'{self.account.hq}/account/endpoint/activity', headers=self.account.headers, params=params)
+    def print_queue(self):
+        res = requests.get(f'{self.account.hq}/account/queue', headers=self.account.headers)
         if res.status_code == 200:
             return res.json()
-        raise Exception(f'Failed to get activity (reason:{res.status_code})')
+        raise Exception(res.text)
 
     @verify_credentials
     def activate_ttp(self, ttp, run_code):
@@ -35,11 +33,30 @@ class DetectController:
             json=dict(run_code=run_code)
         )
         if res.status_code != 200:
-            raise Exception(f'Failed to activate: {res.text}')
+            raise Exception(res.text)
 
     @verify_credentials
     def deactivate_ttp(self, ttp):
         """ Deactivate a TTP so endpoints will stop running it """
         res = requests.delete(f'{self.account.hq}/account/activation/{ttp}', headers=self.account.headers)
         if res.status_code != 200:
-            raise Exception(f'Failed to deactivate: {res.text}')
+            raise Exception(res.text)
+
+    @verify_credentials
+    def describe_activity(self, days=7, ttp=None):
+        """ Get report for an Account """
+        params = dict(days=days)
+        route = f'/{ttp}' if ttp else ''
+        res = requests.get(f'{self.account.hq}/account/report{route}', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
+
+    @verify_credentials
+    def export_report(self, days=7):
+        """ Generate a redirect URL to a data dump """
+        params = dict(days=days)
+        res = requests.get(f'{self.account.hq}/account/report-export', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.url
+        raise Exception(res.text)
